@@ -35,6 +35,7 @@
 #include <QProcess>
 #include <QProxyStyle>
 #include <QToolButton>
+#include <QMainWindow>
 
 #ifdef PRINTER_ENABLE
 #include <QPrinter>
@@ -177,6 +178,8 @@ Variables
   CFMan *fman;
   CImgViewer *img_viewer;
 
+  QTextBrowser md_viewer;
+
   CSpellchecker *spellchecker;
   QStringList spellcheckers;
   QString cur_spellchecker;
@@ -953,6 +956,11 @@ View menu callbacks
   void view_stay_on_top();
   void view_darker();
 
+#if QT_VERSION >= 0x051400
+  void view_preview_md();
+#endif
+
+
 /*-----------------------------*/
 
 /*
